@@ -2,6 +2,7 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+import json
 import logging
 import os
 import sys
@@ -15,7 +16,7 @@ import cfnlint.config
 import cfnlint.formatters
 import cfnlint.decode
 import cfnlint.maintenance
-from cfnlint.helpers import REGIONS
+from cfnlint.helpers import REGIONS, REGISTRY_SCHEMAS
 
 LOGGER = logging.getLogger('cfnlint')
 DEFAULT_RULESDIR = os.path.join(os.path.dirname(__file__), 'rules')
@@ -39,7 +40,7 @@ class UnexpectedRuleException(CfnLintExitException):
     """When processing a rule fails in an unexpected way"""
 
 
-def run_cli(filename, template, rules, regions, override_spec, build_graph, mandatory_rules=None):
+def run_cli(filename, template, rules, regions, override_spec, build_graph, registry_schemas, mandatory_rules=None):
     """Process args and run"""
 
     if override_spec:
@@ -49,6 +50,13 @@ def run_cli(filename, template, rules, regions, override_spec, build_graph, mand
         template_obj = Template(filename, template, regions)
         template_obj.build_graph()
 
+    if registry_schemas:
+        for path in registry_schemas:
+            if path and os.path.isdir(os.path.expanduser(path)):
+                for f in os.listdir(path):
+                    with open(os.path.join(path, f)) as schema:
+                        REGISTRY_SCHEMAS.append(json.load(schema))
+
     return run_checks(filename, template, rules, regions, mandatory_rules)
 
 
@@ -67,7 +75,6 @@ def get_exit_code(matches):
 
 
 def get_formatter(fmt):
-    """ Get Formatter"""
     formatter = {}
     if fmt:
         if fmt == 'quiet':
@@ -88,7 +95,6 @@ def get_formatter(fmt):
 
 
 def get_rules(append_rules, ignore_rules, include_rules, configure_rules=None, include_experimental=False, mandatory_rules=None):
-    """Get rules"""
     rules = RulesCollection(ignore_rules, include_rules, configure_rules,
                             include_experimental, mandatory_rules)
     rules_paths = [DEFAULT_RULESDIR] + append_rules
